@@ -24,6 +24,7 @@ def binary_binned_auroc(
     """
     Compute AUROC, which is the area under the ROC Curve, for binary classification.
     Its class version is ``torcheval.metrics.BinaryBinnedAUROC``.
+    See also :func:`multiclass_binned_auroc <torcheval.metrics.functional.multiclass_binned_auroc>`
 
     Args:
         input (Tensor): Tensor of label predictions
@@ -92,6 +93,10 @@ def _binary_binned_auroc_update_input_check(
             "The `input` and `target` should have the same shape, "
             f"got shapes {input.shape} and {target.shape}."
         )
+    if len(input.shape) > 2:
+        raise ValueError(
+            f"`input` is expected to be two dimensions or less, but got {len(input.shape)}D tensor."
+        )
     if num_tasks == 1:
         if len(input.shape) > 1:
             raise ValueError(
@@ -144,6 +149,7 @@ def multiclass_binned_auroc(
     """
     Compute AUROC, which is the area under the ROC Curve, for multiclass classification.
     Its class version is :obj:`torcheval.metrics.MulticlassAUROC`.
+    See also :func:`binary_binned_auroc <torcheval.metrics.functional.binary_binned_auroc>`
 
     Args:
         input (Tensor): Tensor of label predictions
@@ -159,15 +165,14 @@ def multiclass_binned_auroc(
                 the metric for every class.
 
     Examples::
-
         >>> import torch
         >>> from torcheval.metrics.functional import multiclass_binned_auroc
-        >>> input = torch.tensor([[0.1, 0.1, 0.1, 0.1], [0.5, 0.5, 0.5, 0.5], [0.7, 0.7, 0.7, 0.7], [0.8, 0.8, 0.8, 0.8]])
-        >>> target = torch.tensor([0, 1, 2, 3])
-        >>> multiclass_auroc(input, target, num_classes=4, threshold = 5)
-        0.5
-        >>> multiclass_binned_auroc(input, target, num_classes=4, threshold = 5, average=None)
-        tensor([0.0000, 0.3333, 0.6667, 1.0000])
+        >>> input = torch.tensor([[0.1, 0.2, 0.1], [0.4, 0.2, 0.1], [0.6, 0.1, 0.2], [0.4, 0.2, 0.3], [0.6, 0.2, 0.4]])
+        >>> target = torch.tensor([0, 1, 2, 1, 0])
+        >>> multiclass_binned_auroc(input, target, num_classes=3, threshold=5)
+        tensor(0.4000)
+        >>> multiclass_binned_auroc(input, target, num_classes=3, threshold=5, average=None)
+        tensor([0.5000, 0.2500, 0.2500, 0.0000, 1.0000])
     """
     threshold = _create_threshold_tensor(
         threshold,
